<template>
  <div class="app-container">
    <el-card class="box-card" style="width: 100%;margin-top: 15px" shadow="never">
      <!--搜索条件-->
      <div class="filter-container">
        <my-search ref="searchBar" :items="items" @search="fifterForm"></my-search>
      </div>
      <el-row style="margin-top: 8px">
        <el-col>
          <!--列表-->
          <my-table ref="myTable" :filter="filterFrom" :table="table"/>
        </el-col>
      </el-row>
    </el-card>
    <!-- 审核-->
    <audit v-if="auditShow" :setting="setting" @close="auditShow=false" @search="search"/>
    <!-- 新增-->
    <edit v-if="editShow" :setting="setting" @close="editShow=false" @search="search"/>
    <!-- 详情 -->
    <detail v-if="detailShow" :setting="setting" @close="detailShow=false"></detail>
  </div>
</template>

<script>
import MyTable from "@/components/myTable/myTable";
import SettingIplatform from '@/utils/settingIplatform';
import detail from  '@/views/projectManage/audit/detail'
import * as DateFormatter from '@/utils/DateFormatter';
import items from './items'
import audit from './audit'
import edit from './edit'
export default {
  name: "index",
  components: { MyTable,audit, edit,detail },
  data() {
    return {
      // 搜索框
      items: items,
      // 搜索条件
      filterFrom: {
        projectName: null,  // 项目总数
        projectCode: null, // 项目编号
        projectCategoryId: null, // 分类
        buildOrgId: null, // 建设单位
        auditStatus: null, // 状态  0未审核 1不通过 2通过
        sourceStatus: null, // 类型  0归档 1新增
        approvalDate: null, // 批复时间
        createTime: null // 创建时间
      },
      auditShow:false,
      editShow:false,
      detailShow:false,
      setting:{
        id:null,
        title:'审核'
      },
      // 表格数据
      table: {
        showIndex: true, // 是否显示序号
        expand: false, // 是否显示详情数据
        url: SettingIplatform.apiBaseURL + '/pc/p/project/info/audit/list', // 请求地址
        // 工具条
        tools: {
          columnsCtrl: {// 列控制按钮
            show: false
          },
          generalExport: {// 通用导出按钮
            show: false
          },
          // 自定义工具条按钮
          custom: [
            {
              name: '新增',
              click: () => {
                this.showAdd(null)
              }
            },
            {
              name: '项目导入',
              click: () => {

              }
            },
            {
              name: '导入记录',
              click: () => {

              }
            }
          ]
        },
        // 列信息
        columns: [
          {title: '项目名称', field: 'projectName', align: 'left', width: '240px'},
          {title: '编号', field: 'projectCode', align: 'center', width: '180px'},
          {title: '分类', field: 'projectCategoryName', align: 'center', width: '150px'},
          {title: '建设单位', field: 'buildOrgName', align: 'center', width: '200px'},
          {title: '批复时间', field: 'approvalDate', align: 'center', width: '180px',
            formatter: row => {
              return { value: DateFormatter.LongToDate(row.approvalDate) }
            }
          },
          {title: '创建时间', field: 'createTime', align: 'center', width: '180px',
            formatter: row => {
              return { value: DateFormatter.LongToDateTime(row.createTime) }
            }
          },
          {
            title: '类型', field: 'sourceStatus', align: 'center', width: '120px',
            formatter: row => {
              return {value: row.sourceStatus == 0 ? '归档' : '新增'}
            }
          },
          {
            title: '状态', field: 'auditStatus', align: 'center', width: '120px',
            formatter: row => {
              let value = ''
              if (row.sourceStatus == 0) {
                // 归档
                if (row.archiveStatus == 0) {
                  value = '未审核'
                } else if (row.archiveStatus == 1) {
                  value = '不通过'
                } else if (row.archiveStatus == 2) {
                  value = '通过'
                } else {
                  value = ''
                }
              }
              if (row.sourceStatus == 1) {
                // 新增
                if (row.auditStatus == 0) {
                  value = '未审核'
                } else if (row.auditStatus == 1) {
                  value = '不通过'
                } else if (row.auditStatus == 2) {
                  value = '通过'
                } else {
                  value = ''
                }
              }
              return {value: value}
            }
          },
        ],
        // 操作信息
        operation: {
          width: 180,
          align:'center',
          show: true, // 显示操作列
          attr: [
            {
              title: '审核',
              events: row => {
                this.showAudit(row)
              },
              hidden:(row) => {
                if (row.sourceStatus == 0 && row.archiveStatus !== 0) {
                  return true
                }
                if (row.sourceStatus == 1 && row.auditStatus !== 0) {
                  return true
                }
              }
            },
            {
              title: '详情',
              events: row => {
                this.showDetail(row.id)
              }
            }
          ]
        },
        paging: {
          show: true, // 显示分页
          // 分页信息
          page: {
            small: false,
            pageNum: 1,
            pageSize: 10,
            total: 0
          }
        }
      },
    }
  },
  methods:{
    // 新增
    showAdd(){
      this.setting = {
        title:'新增项目',
        id:null
      }
      this.editShow = true
    },
    showAudit(row){
      this.setting = {
        title:'审核',
        id: row.id,
        sourceStatus: row.sourceStatus
      }
      this.auditShow = true
    },
    showDetail(id){
      this.setting = {
        id: id,
        title:'项目详情'
      }
      this.detailShow = true
    },
    // 查询table列表
    search(pageNum) {
      if (pageNum != undefined) {
        this.$refs.myTable.search(pageNum)
      } else {
        this.$refs.myTable.search()
      }
    },
    fifterForm(params) {
      this.filterFrom = Object.assign(this.filterFrom, params)
      this.search(1)
    }
  }
}
</script>

<style scoped>

</style>
